@@ -13,17 +13,23 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( kto_check kto_check_str kto_check_blz
    kto_check_pz generate_lut generate_lut2 lut_cleanup lut_valid
    lut_init kto_check_init copy_lutfile lut_multiple lut_filialen
-   lut_name lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz
-   lut_aenderung lut_loeschung lut_nachfolge_blz lut_info iban2bic
+   lut_blz lut_name lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz
+   lut_aenderung lut_loeschung lut_nachfolge_blz
+   lut_blz1 lut_name1 lut_name_kurz1 lut_plz1 lut_ort1 lut_pan1 lut_bic1 lut_pz1
+   lut_aenderung1 lut_loeschung1 lut_nachfolge_blz1
+   lut_info iban2bic pz2str
    iban_gen check_iban ipi_check ipi_gen set_verbose_debug
+   retval2txt retval2txt_short retval2utf8 retval2html retval2dos
    kto_check_retval2txt kto_check_retval2txt_short kto_check_retval2utf8
    kto_check_retval2html dump_lutfile kto_check_retval2dos
-   konto_check_at kto_check_at_str generate_lut_at %kto_retval
-   %kto_retval_kurz );
+   lut_suche_blz lut_suche_pz lut_suche_plz lut_suche_bic
+   lut_suche_namen lut_suche_namen_kurz lut_suche_ort
+   konto_check_at kto_check_at_str generate_lut_at
+   %kto_retval %kto_retval_kurz );
 
-our @EXPORT = qw( kto_check lut_init kto_check_blz kto_check_at %kto_retval );
+our @EXPORT = qw( lut_init kto_check kto_check_blz kto_check_at %kto_retval );
 
-our $VERSION = '3.0';
+our $VERSION = '3.2.1';
 
 require XSLoader;
 XSLoader::load('Business::KontoCheck', $VERSION);
@@ -38,6 +44,7 @@ sub lut_info
    my $info2;
    my $valid1;
    my $valid2;
+   my $lut_dir;
    my $args;
 
    if(scalar(@_)==1){
@@ -49,11 +56,11 @@ sub lut_info
       $args=-2;
    }
    if(wantarray()){
-      $ret=lut_info_i($lut_name,1+$args,$info1,$valid1,$info2,$valid2);
-      return ($ret,$info1,$valid1,$info2,$valid2);
+      $ret=lut_info_i($lut_name,1+$args,$info1,$valid1,$info2,$valid2,$lut_dir);
+      return ($ret,$info1,$valid1,$info2,$valid2,$lut_dir);
    }
    else{
-      $ret=lut_info_i($lut_name,$args,$info1,$valid1,$info2,$valid2);
+      $ret=lut_info_i($lut_name,$args,$info1,$valid1,$info2,$valid2,$lut_dir);
       return $ret;
    }
 }
@@ -133,6 +140,102 @@ sub lut_filialen
    }
 }
 
+sub lut_suche_bic
+{
+   if(wantarray()){
+      return lut_suche_c(1,1,@_);
+   }
+   else{
+      return lut_suche_c(0,1,@_);
+   }
+}
+
+
+sub lut_suche_namen
+{
+   if(wantarray()){
+      return lut_suche_c(1,2,@_);
+   }
+   else{
+      return lut_suche_c(0,2,@_);
+   }
+}
+
+
+sub lut_suche_namen_kurz
+{
+   if(wantarray()){
+      return lut_suche_c(1,3,@_);
+   }
+   else{
+      return lut_suche_c(0,3,@_);
+   }
+}
+
+
+sub lut_suche_ort
+{
+   if(wantarray()){
+      return lut_suche_c(1,4,@_);
+   }
+   else{
+      return lut_suche_c(0,4,@_);
+   }
+}
+
+
+sub lut_suche_blz
+{
+   if(wantarray()){
+      return lut_suche_i(1,1,@_);
+   }
+   else{
+      return lut_suche_i(0,1,@_);
+   }
+}
+
+
+sub lut_suche_pz
+{
+   if(wantarray()){
+      return lut_suche_i(1,2,@_);
+   }
+   else{
+      return lut_suche_i(0,2,@_);
+   }
+}
+
+
+sub lut_suche_plz
+{
+   if(wantarray()){
+      return lut_suche_i(1,3,@_);
+   }
+   else{
+      return lut_suche_i(0,3,@_);
+   }
+}
+
+
+
+sub lut_blz
+{
+   my $r;
+
+   $r=lut_blz_i(@_);
+   if(wantarray()){
+      return ($r,$Business::KontoCheck::kto_retval{$r},$Business::KontoCheck::kto_retval_kurz{$r});
+   }
+   else{
+      return $r;
+   }
+}
+
+sub lut_blz1
+{
+   return lut_blz_i(@_);
+}
+
 sub lut_name
 {
    my $r=1;
@@ -147,6 +250,13 @@ sub lut_name
    }
 }
 
+sub lut_name1
+{
+   my $r=1;
+
+   return lut_name_i($r,@_);
+}
+
 sub lut_name_kurz
 {
    my $r=1;
@@ -161,6 +271,13 @@ sub lut_name_kurz
    }
 }
 
+sub lut_name_kurz1
+{
+   my $r=1;
+
+   return lut_name_kurz_i($r,@_);
+}
+
 sub lut_plz
 {
    my $r=1;
@@ -175,6 +292,13 @@ sub lut_plz
    }
 }
 
+sub lut_plz1
+{
+   my $r=1;
+
+   return lut_plz_i($r,@_);
+}
+
 sub lut_ort
 {
    my $r=1;
@@ -189,6 +313,13 @@ sub lut_ort
    }
 }
 
+sub lut_ort1
+{
+   my $r=1;
+
+   return lut_ort_i($r,@_);
+}
+
 sub lut_pan
 {
    my $r=1;
@@ -203,6 +334,13 @@ sub lut_pan
    }
 }
 
+sub lut_pan1
+{
+   my $r=1;
+
+   return lut_pan_i($r,@_);
+}
+
 sub lut_bic
 {
    my $r=1;
@@ -217,6 +355,13 @@ sub lut_bic
    }
 }
 
+sub lut_bic1
+{
+   my $r=1;
+
+   return lut_bic_i($r,@_);
+}
+
 sub lut_pz
 {
    my $r=1;
@@ -231,6 +376,13 @@ sub lut_pz
    }
 }
 
+sub lut_pz1
+{
+   my $r=1;
+
+   return lut_pz_i($r,@_);
+}
+
 sub lut_aenderung
 {
    my $r=1;
@@ -245,6 +397,13 @@ sub lut_aenderung
    }
 }
 
+sub lut_aenderung1
+{
+   my $r=1;
+
+   return lut_aenderung_i($r,@_);
+}
+
 sub lut_loeschung
 {
    my $r=1;
@@ -259,6 +418,13 @@ sub lut_loeschung
    }
 }
 
+sub lut_loeschung1
+{
+   my $r=1;
+
+   return lut_loeschung_i($r,@_);
+}
+
 sub lut_nachfolge_blz
 {
    my $r=1;
@@ -273,12 +439,50 @@ sub lut_nachfolge_blz
    }
 }
 
+sub lut_nachfolge_blz1
+{
+   my $r=1;
+
+   return lut_nachfolge_blz_i($r,@_);
+}
+
 
 %Business::KontoCheck::kto_retval = (
+-110 => 'wahrscheinlich OK; es wurde allerdings ein (weggelassenes) Unterkonto angefgt',
+-109 => 'Ungltige Signatur im Default-Block',
+-108 => 'Die maximale Anzahl Eintrge fr den Default-Block wurde erreicht',
+-107 => 'Es wurde noch kein Default-Block angelegt',
+-106 => 'Der angegebene Schlssel wurde im Default-Block nicht gefunden',
+-105 => 'Der Datensatz ist nicht mehr gltig, aber jnger als der andere',
+-104 => 'Die Auftraggeber-Kontonummer des C-Datensatzes unterscheidet sich von der des A-Satzes',
+-103 => 'Die Auftraggeber-Bankleitzahl des C-Datensatzes unterscheidet sich von der des A-Satzes',
+-102 => 'Die DTA-Datei enthlt (unzulssige) Zeilenvorschbe',
+-101 => 'ungltiger Typ bei einem Erweiterungsblock eines C-Datensatzes',
+-100 => 'Es wurde ein C-Datensatz erwartet, jedoch ein E-Satz gefunden',
+ -99 => 'Es wurde ein C-Datensatz erwartet, jedoch ein E-Satz gefunden',
+ -98 => 'Es wurde ein C-Datensatzerweiterung erwartet, jedoch ein C-Satz gefunden',
+ -97 => 'Es wurde ein C-Datensatzerweiterung erwartet, jedoch ein E-Satz gefunden',
+ -96 => 'Die Anzahl Erweiterungen pat nicht zur Blocklnge',
+ -95 => 'Ungltige Zeichen in numerischem Feld',
+ -94 => 'Ungltige Zeichen im Textfeld',
+ -93 => 'Die Whrung des DTA-Datensatzes ist nicht Euro',
+ -92 => 'In einem DTA-Datensatz wurde kein Betrag angegeben',
+ -91 => 'Ungltiger Textschlssel in der DTA-Datei',
+ -90 => 'Fr ein (alphanumerisches) Feld wurde kein Wert angegeben',
+ -89 => 'Die Startmarkierung des A-Datensatzes wurde nicht gefunden',
+ -88 => 'Die Startmarkierung des C-Datensatzes wurde nicht gefunden',
+ -87 => 'Die Startmarkierung des E-Datensatzes wurde nicht gefunden',
+ -86 => 'Die Satzlnge eines C-Datensatzes mu zwischen 187 und 622 Byte betragen',
+ -85 => 'Die Satzlnge eines A- bzw. E-Satzes mu 128 Byte betragen',
+ -84 => 'als Whrung in der DTA-Datei ist nicht Euro eingetragen',
+ -83 => 'das Ausfhrungsdatum ist zu frh oder zu spt (max. 15 Tage nach Dateierstellung)',
+ -82 => 'das Datum ist ungltig',
+ -81 => 'Formatfehler in der DTA-Datei',
+ -80 => 'die DTA-Datei enthlt Fehler',
  -79 => 'ungltiger Suchbereich angegeben (unten>oben)',
  -78 => 'Die Suche lieferte kein Ergebnis',
  -77 => 'BAV denkt, das Konto ist falsch (konto_check hlt es fr richtig)',
- -76 => 'User-Blocks mssen einen Typ > 1000 haben',
+ -76 => 'User-Blocks mssen einen Typ > 500 haben',
  -75 => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
  -74 => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
  -73 => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
@@ -362,11 +566,47 @@ sub lut_nachfolge_blz
    5 => 'Der Datensatz enthlt kein Gltigkeitsdatum',
    6 => 'Die Datei ist im alten LUT-Format (1.0/1.1)',
    7 => 'ok; es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert',
+   8 => 'In der DTAUS-Datei wurden kleinere Fehler gefunden',
+   9 => 'ok; es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)',
+  10 => 'ok; der Wert fr den Schlssel wurde berschrieben',
+  11 => 'wahrscheinlich ok; die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten',
+  12 => 'wahrscheinlich ok; die Kontonummer enthlt eine Unterkontonummer',
 
+'OK_UNTERKONTO_ATTACHED'                 => 'wahrscheinlich OK; es wurde allerdings ein (weggelassenes) Unterkonto angefgt',
+'KTO_CHECK_DEFAULT_BLOCK_INVALID'        => 'Ungltige Signatur im Default-Block',
+'KTO_CHECK_DEFAULT_BLOCK_FULL'           => 'Die maximale Anzahl Eintrge fr den Default-Block wurde erreicht',
+'KTO_CHECK_NO_DEFAULT_BLOCK'             => 'Es wurde noch kein Default-Block angelegt',
+'KTO_CHECK_KEY_NOT_FOUND'                => 'Der angegebene Schlssel wurde im Default-Block nicht gefunden',
+'LUT2_NO_LONGER_VALID_BETTER'            => 'Der Datensatz ist nicht mehr gltig, aber jnger als der andere',
+'DTA_SRC_KTO_DIFFERENT'                  => 'Die Auftraggeber-Kontonummer des C-Datensatzes unterscheidet sich von der des A-Satzes',
+'DTA_SRC_BLZ_DIFFERENT'                  => 'Die Auftraggeber-Bankleitzahl des C-Datensatzes unterscheidet sich von der des A-Satzes',
+'DTA_CR_LF_IN_FILE'                      => 'Die DTA-Datei enthlt (unzulssige) Zeilenvorschbe',
+'DTA_INVALID_C_EXTENSION'                => 'ungltiger Typ bei einem Erweiterungsblock eines C-Datensatzes',
+'DTA_FOUND_SET_A_NOT_C'                  => 'Es wurde ein C-Datensatz erwartet, jedoch ein E-Satz gefunden',
+'DTA_FOUND_SET_E_NOT_C'                  => 'Es wurde ein C-Datensatz erwartet, jedoch ein E-Satz gefunden',
+'DTA_FOUND_SET_C_NOT_EXTENSION'          => 'Es wurde ein C-Datensatzerweiterung erwartet, jedoch ein C-Satz gefunden',
+'DTA_FOUND_SET_E_NOT_EXTENSION'          => 'Es wurde ein C-Datensatzerweiterung erwartet, jedoch ein E-Satz gefunden',
+'DTA_INVALID_EXTENSION_COUNT'            => 'Die Anzahl Erweiterungen pat nicht zur Blocklnge',
+'DTA_INVALID_NUM'                        => 'Ungltige Zeichen in numerischem Feld',
+'DTA_INVALID_CHARS'                      => 'Ungltige Zeichen im Textfeld',
+'DTA_CURRENCY_NOT_EURO'                  => 'Die Whrung des DTA-Datensatzes ist nicht Euro',
+'DTA_EMPTY_AMOUNT'                       => 'In einem DTA-Datensatz wurde kein Betrag angegeben',
+'DTA_INVALID_TEXT_KEY'                   => 'Ungltiger Textschlssel in der DTA-Datei',
+'DTA_EMPTY_STRING'                       => 'Fr ein (alphanumerisches) Feld wurde kein Wert angegeben',
+'DTA_MARKER_A_NOT_FOUND'                 => 'Die Startmarkierung des A-Datensatzes wurde nicht gefunden',
+'DTA_MARKER_C_NOT_FOUND'                 => 'Die Startmarkierung des C-Datensatzes wurde nicht gefunden',
+'DTA_MARKER_E_NOT_FOUND'                 => 'Die Startmarkierung des E-Datensatzes wurde nicht gefunden',
+'DTA_INVALID_SET_C_LEN'                  => 'Die Satzlnge eines C-Datensatzes mu zwischen 187 und 622 Byte betragen',
+'DTA_INVALID_SET_LEN'                    => 'Die Satzlnge eines A- bzw. E-Satzes mu 128 Byte betragen',
+'DTA_WAERUNG_NOT_EURO'                   => 'als Whrung in der DTA-Datei ist nicht Euro eingetragen',
+'DTA_INVALID_ISSUE_DATE'                 => 'das Ausfhrungsdatum ist zu frh oder zu spt (max. 15 Tage nach Dateierstellung)',
+'DTA_INVALID_DATE'                       => 'das Datum ist ungltig',
+'DTA_FORMAT_ERROR'                       => 'Formatfehler in der DTA-Datei',
+'DTA_FILE_WITH_ERRORS'                   => 'die DTA-Datei enthlt Fehler',
 'INVALID_SEARCH_RANGE'                   => 'ungltiger Suchbereich angegeben (unten>oben)',
 'KEY_NOT_FOUND'                          => 'Die Suche lieferte kein Ergebnis',
 'BAV_FALSE'                              => 'BAV denkt, das Konto ist falsch (konto_check hlt es fr richtig)',
-'LUT2_NO_USER_BLOCK'                     => 'User-Blocks mssen einen Typ > 1000 haben',
+'LUT2_NO_USER_BLOCK'                     => 'User-Blocks mssen einen Typ > 500 haben',
 'INVALID_SET'                            => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
 'NO_GERMAN_BIC'                          => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
 'IPI_CHECK_INVALID_LENGTH'               => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
@@ -450,9 +690,45 @@ sub lut_nachfolge_blz
 'LUT2_NO_VALID_DATE'                     => 'Der Datensatz enthlt kein Gltigkeitsdatum',
 'LUT1_SET_LOADED'                        => 'Die Datei ist im alten LUT-Format (1.0/1.1)',
 'LUT1_FILE_GENERATED'                    => 'ok; es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert',
+'DTA_FILE_WITH_WARNINGS'                 => 'In der DTAUS-Datei wurden kleinere Fehler gefunden',
+'LUT_V2_FILE_GENERATED'                  => 'ok; es wurde allerdings eine LUT-Datei im Format 2.0 generiert (Compilerswitch)',
+'KTO_CHECK_VALUE_REPLACED'               => 'ok; der Wert fr den Schlssel wurde berschrieben',
+'OK_UNTERKONTO_POSSIBLE'                 => 'wahrscheinlich ok; die Kontonummer kann allerdings (nicht angegebene) Unterkonten enthalten',
+'OK_UNTERKONTO_GIVEN'                    => 'wahrscheinlich ok; die Kontonummer enthlt eine Unterkontonummer',
 );
 
 %Business::KontoCheck::kto_retval_kurz = (
+-110 => 'OK_UNTERKONTO_ATTACHED',
+-109 => 'KTO_CHECK_DEFAULT_BLOCK_INVALID',
+-108 => 'KTO_CHECK_DEFAULT_BLOCK_FULL',
+-107 => 'KTO_CHECK_NO_DEFAULT_BLOCK',
+-106 => 'KTO_CHECK_KEY_NOT_FOUND',
+-105 => 'LUT2_NO_LONGER_VALID_BETTER',
+-104 => 'DTA_SRC_KTO_DIFFERENT',
+-103 => 'DTA_SRC_BLZ_DIFFERENT',
+-102 => 'DTA_CR_LF_IN_FILE',
+-101 => 'DTA_INVALID_C_EXTENSION',
+-100 => 'DTA_FOUND_SET_A_NOT_C',
+ -99 => 'DTA_FOUND_SET_E_NOT_C',
+ -98 => 'DTA_FOUND_SET_C_NOT_EXTENSION',
+ -97 => 'DTA_FOUND_SET_E_NOT_EXTENSION',
+ -96 => 'DTA_INVALID_EXTENSION_COUNT',
+ -95 => 'DTA_INVALID_NUM',
+ -94 => 'DTA_INVALID_CHARS',
+ -93 => 'DTA_CURRENCY_NOT_EURO',
+ -92 => 'DTA_EMPTY_AMOUNT',
+ -91 => 'DTA_INVALID_TEXT_KEY',
+ -90 => 'DTA_EMPTY_STRING',
+ -89 => 'DTA_MARKER_A_NOT_FOUND',
+ -88 => 'DTA_MARKER_C_NOT_FOUND',
+ -87 => 'DTA_MARKER_E_NOT_FOUND',
+ -86 => 'DTA_INVALID_SET_C_LEN',
+ -85 => 'DTA_INVALID_SET_LEN',
+ -84 => 'DTA_WAERUNG_NOT_EURO',
+ -83 => 'DTA_INVALID_ISSUE_DATE',
+ -82 => 'DTA_INVALID_DATE',
+ -81 => 'DTA_FORMAT_ERROR',
+ -80 => 'DTA_FILE_WITH_ERRORS',
  -79 => 'INVALID_SEARCH_RANGE',
  -78 => 'KEY_NOT_FOUND',
  -77 => 'BAV_FALSE',
@@ -540,6 +816,11 @@ sub lut_nachfolge_blz
    5 => 'LUT2_NO_VALID_DATE',
    6 => 'LUT1_SET_LOADED',
    7 => 'LUT1_FILE_GENERATED',
+   8 => 'DTA_FILE_WITH_WARNINGS',
+   9 => 'LUT_V2_FILE_GENERATED',
+  10 => 'KTO_CHECK_VALUE_REPLACED',
+  11 => 'OK_UNTERKONTO_POSSIBLE',
+  12 => 'OK_UNTERKONTO_GIVEN',
 );
 
 END{ lut_cleanup(); }
@@ -561,7 +842,7 @@ language is german too.
    use Business::KontoCheck;
    use Business::KontoCheck qw( kto_check lut_name lut_blz lut_ort %kto_retval [...] );
 
-   $retval=lut_init([$lut_name[,$required[,$set]]);
+   $retval=lut_init([$lut_name[,$required[,$set]]]);
    $retval=kto_check_init($lut_name[,$required[,$set[,$incremental]]]);
    $retval=kto_check($blz,$kto,$lut_name);
    $retval=kto_check_str($blz,$kto,$lut_name);
@@ -571,19 +852,31 @@ language is german too.
    $retval=generate_lut($inputname,$outputname,$user_info,$lut_version);
    $retval=generate_lut2($inputname,$outputname[,$user_info[,$gueltigkeit[,$felder[,$filialen[,$slots[,$lut_version[,$set]]]]]]]);
 
+   [$@]retval=lut_blz($blz[,$offset])
+   [$@]retval=lut_info($lut_name)
+   [$@]retval=lut_filialen($blz[,$offset])
+   [$@]retval=lut_name($blz[,$offset])
+   [$@]retval=lut_name_kurz($blz[,$offset])
+   [$@]retval=lut_plz($blz[,$offset])
+   [$@]retval=lut_ort($blz[,$offset])
+   [$@]retval=lut_pan($blz[,$offset])
+   [$@]retval=lut_bic($blz[,$offset])
+   [$@]retval=lut_pz($blz[,$offset])
+   [$@]retval=lut_aenderung($blz[,$offset])
+   [$@]retval=lut_loeschung($blz[,$offset])
+   [$@]retval=lut_nachfolge_blz($blz[,$offset])
+
    $retval=lut_valid()
-   @retval=lut_info($lut_name)
-   $retval=lut_filialen($blz[,$offset])
-   $retval=lut_name($blz[,$offset])
-   $retval=lut_name_kurz($blz[,$offset])
-   $retval=lut_plz($blz[,$offset])
-   $retval=lut_ort($blz[,$offset])
-   $retval=lut_pan($blz[,$offset])
-   $retval=lut_bic($blz[,$offset])
-   $retval=lut_pz($blz[,$offset])
-   $retval=lut_aenderung($blz[,$offset])
-   $retval=lut_loeschung($blz[,$offset])
-   $retval=lut_nachfolge_blz($blz[,$offset])
+   $ret=pz2str($pz[,$ret])
+
+   [$@]bic=lut_suche_bic($bic[,$retval])
+   [$@]namen=lut_suche_namen($namen[,$retval])
+   [$@]namen_kurz=lut_suche_namen_kurz($namen_kurz])
+   [$@]ort=lut_suche_ort($ort[,$retval])
+   [$@]blz=lut_suche_blz($blz1[,$blz2[,$retval]])
+   [$@]pz=lut_suche_pz($pz1[,$pz2[,$retval]])
+   [$@]plz=lut_suche_plz($plz1[,$plz2[,$retval]])
+
    $retval=copy_lutfile($old_name,$new_name,$new_slots)
    $retval=dump_lutfile($outputname,$felder)
    $retval=lut_cleanup()
@@ -597,6 +890,11 @@ language is german too.
    $retval=retval2html($retval)
    $retval=retval2utf8($retval)
    $retval=retval2dos($retval)
+   $retval=kto_check_retval2txt($retval)
+   $retval=kto_check_retval2txt_short($retval)
+   $retval=kto_check_retval2html($retval)
+   $retval=kto_check_retval2utf8($retval)
+   $retval=kto_check_retval2dos($retval)
    $retval_txt=$kto_retval{$retval};
 
    $retval=kto_check_at($blz,$kto,$lut_name);
@@ -605,13 +903,9 @@ language is german too.
 
 =head1 DESCRIPTION
 
-Dies ist Business::KontoCheck, ein Programm zum Testen der
-Prfziffern von deutschen und sterreichischen Bankkonten. Es war
-ursprnglich fr die Benutzung mit dem dtaus-Paket von Martin
-Schulze <joey@infodrom.org> und dem lx2l Prprozessor gedacht;
-es lt sich jedoch auch mit beliebigen anderen Programmen
-verwenden. Dies ist die Perl-Version der C-Library (als XSUB
-Modul).
+Dies ist Business::KontoCheck, ein Programm zum Testen der Prfziffern
+von deutschen und sterreichischen Bankkonten. Dies ist die
+Perl-Version der C-Library (als XSUB Modul).
 
 =head1 EXPORT
 
@@ -620,9 +914,8 @@ Es werden defaultmig die Funkionen kto_check und kto_check_str,
 dem sterreichischen Modul) sowie die Variable %kto_retval (fr
 beide Module) exportiert.
 
-Optional knnen auch die Funktionen generate_lut, sowie
-generate_lut_at exportiert werden; in diesem Fall sind die gewnschten
-Funktionen in der use Klausel anzugeben.
+Optional knnen auch eine Reihe weiterer Funktionen exportiert werden;
+diese mssen dann in der use Klausel anzugeben werden.
 
 =head1 DESCRIPTION
 
@@ -652,19 +945,19 @@ Funktionen in der use Klausel anzugeben.
                 werden.
 
   Rckgabewerte:
-     Die Funktion kto_check gibt einen numerischen Wert zurck, whrend die
-     Funktion kto_check_str einen kurzen String zurckgibt.
-     Werte sind definiert3
+     Die Funktion kto_check gibt einen numerischen Wert zurck,
+     whrend die Funktion kto_check_str einen kurzen String
+     zurckgibt.
 
-     Mittels des assoziativen Arrays %kto_retval lassen sich die numerischen
-     und kurzen Rckgabewerte in einen etwas ausfhrlicheren Rckgabetext
-     umwandeln:
+     Mittels des assoziativen Arrays %kto_retval lassen sich die
+     numerischen Rckgabewerte in einen etwas ausfhrlicheren
+     Rckgabetext umwandeln:
 
      $retval_txt=$kto_retval{$retval};
 
 -------------------------------------------------------------------------
 
-  Funktion:  generate_lut()      (LUT-Version 1.0 oder 1.1)
+  Funktion:  generate_lut()      (LUT-Version 1.0 oder 1.1; obsolet)
              generate_lut2()     (LUT-Version 1.0, 1.1 oder 2.0)
 
   Aufgabe:   LUT-Datei generieren
@@ -716,7 +1009,8 @@ Funktionen in der use Klausel anzugeben.
 
 -------------------------------------------------------------------------
 
-  Funktion:  lut_filialen()
+  Funktion:  lut_blz()
+             lut_filialen()
              lut_name()
              lut_name_kurz()
              lut_plz()
@@ -730,16 +1024,18 @@ Funktionen in der use Klausel anzugeben.
 
   Aufgabe:   Bestimmung von Feldern der BLZ-Datei
 
-  Aufruf:    [$@]ret=lut_name($blz[,$filiale])
-             [$@]ret=lut_name_kurz($blz[,$filiale])
-             [$@]ret=lut_plz($blz[,$filiale])
-             [$@]ret=lut_ort($blz[,$filiale])
-             [$@]ret=lut_pan($blz[,$filiale])
-             [$@]ret=lut_bic($blz[,$filiale])
-             [$@]ret=lut_pz($blz[,$filiale])
-             [$@]ret=lut_aenderung($blz[,$filiale])
-             [$@]ret=lut_loeschung($blz[,$filiale])
-             [$@]ret=lut_nachfolge_blz($blz[,$filiale])
+  Aufruf:    [$@]ret=lut_blz($blz[,$filiale[,$ret]])
+             [$@]ret=lut_name($blz[,$filiale[,$ret]])
+             [$@]ret=lut_name_kurz($blz[,$filiale[,$ret]])
+             [$@]ret=lut_plz($blz[,$filiale[,$ret]])
+             [$@]ret=lut_ort($blz[,$filiale[,$ret]])
+             [$@]ret=lut_pan($blz[,$filiale[,$ret]])
+             [$@]ret=lut_bic($blz[,$filiale[,$ret]])
+             [$@]ret=lut_pz($blz[,$filiale[,$ret]])
+             [$@]ret=lut_aenderung($blz[,$filiale[,$ret]])
+             [$@]ret=lut_loeschung($blz[,$filiale[,$ret]])
+             [$@]ret=lut_nachfolge_blz($blz[,$filiale[,$ret]])
+             $ret=pz2str($pz[,$ret])
 
    Die Funktionen bestimmen die diversen Felder der BLZ-Datei zu einer
    gegebenen BLZ. Falls der optionale Parameter $filiale angegeben
@@ -748,11 +1044,15 @@ Funktionen in der use Klausel anzugeben.
    einer BLZ lt sich mittels der Funktion $cnt=lut_filialen($blz)
    bestimmen.
 
-   Alle Funktionen lassen sich sowohl im skalaren als auch im Array-
-   Kontext aufrufen. Bei Aufruf in skalarem Kontext wird der jeweilige
-   Wert zurckgegeben; bei Aufruf im Array-Kontext wird auerdem noch
-   der Rckgabestatus der Funktion als Zahl, String (lang) und String
-   (kurz) zurckgegeben. Beispiel:
+   Die Funktion pz2str() wandelt eine numerische Prfziffermethode
+   (wie sie z.B. von lut_pz() zurckgegeben wird) in einen
+   zweistelligen String um.
+
+   Alle Funktionen (auer pz2str) lassen sich sowohl im skalaren als
+   auch im Array-Kontext aufrufen. Bei Aufruf in skalarem Kontext wird
+   der jeweilige Wert zurckgegeben; bei Aufruf im Array-Kontext wird
+   auerdem noch der Rckgabestatus der Funktion als Zahl, String
+   (lang) und String (kurz) zurckgegeben. Beispiel:
 
    $ret=lut_name("66090800") liefert fr $ret den Wert "BBBank",
    @ret=lut_name("66090800") liefert ein Array mit den Werten
@@ -762,6 +1062,106 @@ Funktionen in der use Klausel anzugeben.
    @ret=lut_name("660908") liefert ein Array mit den Werten
    @ret=("",-5,"die Bankleitzahl ist nicht achtstellig","INVALID_BLZ_LENGTH")
 
+   Falls der Aufruf im Array-Kontext nicht gewnscht ist, gibt es noch
+   alternative Funktionen, die nur in skalarem Kontext arbeiten: 
+
+   -------------------------------------------------------------------------
+
+  Funktion:  lut_blz1()
+             lut_filialen1()
+             lut_name1()
+             lut_name_kurz1()
+             lut_plz1()
+             lut_ort1()
+             lut_pan1()
+             lut_bic1()
+             lut_pz1()
+             lut_aenderung1()
+             lut_loeschung1()
+             lut_nachfolge_blz1()
+
+  Aufgabe:   Bestimmung von Feldern der BLZ-Datei (skalarer Kontext)
+
+  Aufruf:    $ret=lut_blz1($blz[,$filiale[,$ret]])
+             $ret=lut_name1($blz[,$filiale[,$ret]])
+             $ret=lut_name_kurz1($blz[,$filiale[,$ret]])
+             $ret=lut_plz1($blz[,$filiale[,$ret]])
+             $ret=lut_ort1($blz[,$filiale[,$ret]])
+             $ret=lut_pan1($blz[,$filiale[,$ret]])
+             $ret=lut_bic1($blz[,$filiale[,$ret]])
+             $ret=lut_pz1($blz[,$filiale[,$ret]])
+             $ret=lut_aenderung1($blz[,$filiale[,$ret]])
+             $ret=lut_loeschung1($blz[,$filiale[,$ret]])
+             $ret=lut_nachfolge_blz1($blz[,$filiale[,$ret]])
+             $ret=pz2str1($pz[,$ret])
+
+   Die Funktionen entsprechen den Funktionen ohne die angehngte "1";
+   allerdings arbeiten sie ausschlielich im skalaren Kontext. Das ist
+   z.B. vorteilhaft, wenn man den Rckgabewert der Funktion in einem
+   anderen Funktionsaufruf benutzen will. Der Rckgabewert der
+   Funktion kann mittels des optionalen Parameters $ret bestimmt
+   werden.
+
+-------------------------------------------------------------------------
+
+  Funktion:  lut_suche_blz()
+             lut_suche_bic()
+             lut_suche_namen()
+             lut_suche_namen_kurz()
+             lut_suche_ort()
+             lut_suche_pz()
+             lut_suche_plz()
+
+  Aufgabe:  Suche von Banken (nach Feldern der BLZ-Datei)
+
+  Aufruf:    [$@]ret=lut_suche_bic($bic[,$retval])
+             [$@]ret=lut_suche_namen($namen[,$retval])
+             [$@]ret=lut_suche_namen_kurz($namen_kurz[,$retval])
+             [$@]ret=lut_suche_ort($ort[,$retval])
+
+             [$@]ret=lut_suche_blz($blz1[,$blz2[,$retval]])
+             [$@]ret=lut_suche_pz($pz1[,$pz2[,$retval]])
+             [$@]ret=lut_suche_plz($plz1[,$plz2[,$retval]])
+
+   Mit diesen Funktionen lassen sich Banken suchen, die bestimmte
+   Kriterien erfllen. Bei alphanumerischer Suche (BIC, Name,
+   Kurzname, Ort) kann ein vollstndiger Name oder Namensanfang
+   angegeben werden. So findet z.B. eine Suche lut_suche_ort("aa") die
+   Banken in in Aach, Aachen, Aalen und Aarbergen, whrend eine Suche
+   wie lut_suche_ort("aac") nur die Banken in Aach und Aachen findet.
+
+   Bei numerischer Suche (BLZ, Prfziffer oder PLZ) kann ein Bereich
+   spezifiziert werden. Falls der zweite Suchparameter nicht angegeben
+   wird (oder 0 ist), werden Banken gesucht, die genau auf den
+   Parameter passen.
+
+   Diese Funktionen knnen sowohl in skalarem als auch im
+   Listenkontext aufgerufen werden. Bei Aufruf in skalarem Kontext
+   geben sie eine Referenz auf ein Array mit Bankleitzahlen zurck,
+   die die Kriterien erfllen; bei Aufruf im Listenkontext werden (bis
+   zu) drei Referenzen zurckgegeben. Die erste zeigt auf das Array
+   mit Bankleitzahlen, die zweite auf ein Array mit Indizes der
+   jeweiligen Zweigstellen und die dritte auf ein Array mit den
+   jeweiligen Werten des gesuchten Feldes.
+
+   In dem (optionalen) Parameter $retval wird der numerischer
+   Rckgabewert der Funktion (1 bei Erfolg, oder negative
+   Statusmeldung) zurckgeliefert.. Mittels des assoziativen Arrays
+   %kto_retval{$retval} knnen diese Rckgabewerte in Klartext
+   konvertiert werden.
+
+   Beispiele:
+   $blz_p=lut_suche_ort("mannheim");
+   @blz=@$blz_p;     # Array mit allen Banken in Mannheim
+
+   ($blz_p,$idx_p)=lut_suche_ort("mannheim");
+   @blz=@$blz_p;     # Array mit allen Banken in Mannheim
+   @idx=@$idx_p;     # Array der Zweigstellen
+
+   ($blz_p,$idx_p,$ort_p)=lut_suche_ort("aa");
+   @blz=@$blz_p;     # Array mit Banken in Stdten, die mit "aa" beginnen
+   @idx=@$idx_p;     # Array der Zweigstellen
+   @ort=@$ort_p;     # Array der jeweiligen Orte
 
 -------------------------------------------------------------------------
 
@@ -863,35 +1263,23 @@ Funktionen in der use Klausel anzugeben.
 
 -------------------------------------------------------------------------
 
-
-=head1 BUGS der Version 2.x:
-
-Die alten Problemflle aus Version 2.x sind ab Version 3.0 behoben:
-
- - Die Funktion generate_lut() benutzt einen eigenen Variablensatz, so
-   da keine Interferenzen mit den Testroutinen auftreten (das git noch
-   nicht fr generate_lut_at()!).
-
- - Die Bibliothek ist jetzt threadfest
-
- - Es ist mglich, die Initialisierung mehrfach aufzurufen; der vorher
-    allokierte Speicher wird dabei automatisch freigegeben. Auch eine
-    inkrementelle Initialisierung (bei der nur einige Blocks der
-    LUT-Datei nachgeladen werden) ist mglich. Falls in der LUT-Datei
-    zwei Datenstze enthalten sind (und nicht ein bestimmter
-    ausgewhlt wird), erfolgt die (Neu-)Initialisierung in
-    Abhngigkeit vom aktuellen Datum.
-
-
 =head1 SEE ALSO
 
-Eine ausfhrliche Beschreibung der Prfziffermethoden und das Format der
-LUT-Datei findet sich im C-Quellcode.
+Eine ausfhrliche Beschreibung der Prfziffermethoden und das Format
+der LUT-Datei findet sich im C-Quellcode. Ein Link zur offiziellen
+Beschreibung der Prfziffermethoden u.a. (von der Deutschen
+Bundesbank) findet sich auf der Webseite zu konto_check unter
+http://www.informatik.hs-mannheim.de/konto_check/konto_check.php?ausgabe=3
 
-Eine Mailingliste zu konto_check findet sich auf SourceForge.net unter
-http://sourceforge.net/mail/?group_id=199719
+Auf SourceForge.net gibt es unter http://sourceforge.net/mail/?group_id=199719
+auch eine Mailingliste. Der Traffic ist sehr gering, maximal meist ein bis zwei
+Emails/Monat.
 
-Die aktuelle Version findet sich unter http://www.informatik.hs-mannheim.de/konto_check
+Die aktuelle Version findet sich auf CPAN unter
+http://search.cpan.org/~michel/Business-KontoCheck oder auf
+Sourceforge unter http://sourceforge.net/projects/kontocheck/develop
+Dort ist auch ein SVN Repository, in dem die neuesten Versionen und
+Bugfixes zu finden sind.
 
 =head1 AUTHOR
 
@@ -899,7 +1287,7 @@ Michael Plugge, E<lt>m.plugge@hs-mannheim.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2008 by Michael Plugge
+Copyright (C) 2007-2010 by Michael Plugge
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself, either Perl version 5.8.8 or, at your option,
